
**********************************************************************************************************************************
**********************************************************************************************************************************
* REPLICATION FILE 

* Title: Parental Beliefs about Returns to Different Types of Investments in School Children
* Authors: Orazio Attanasio, Teodora Boneva, Christopher Rauh
* Date: 2020
* Journal: Journal of Human Resources
* Note: This dofile replicates the results as reported in the journal article. 

**********************************************************************************************************************************
**********************************************************************************************************************************

clear all
set more off

*set path to local directory
local path "C:/Users/XXX" 

*load data
use "`path'/parental_beliefs_data.dta"

*create folder 'Output' and set path
cd "`path'/Output"

 
**********************************************************************************************************************************
**********************************************************************************************************************************
*     SECTION 3.1: Summary statistics 
**********************************************************************************************************************************
**********************************************************************************************************************************

********************************************************************************
*  Table 3: Summary statistics of sample 
********************************************************************************

sutex parent_male parent_age otheradult otherlanguage work_fulltime work_parttime parent_degree hhincome ///
oneparentuni totalchildren private child_male schoolyear academic child_age, lab title("Summary statistics") ///
file (table3.tex) key(tab:summarystats) replace
 
 
********************************************************************************
*  Appendix Table A.1: Summary statistics of Ofsted ratings
********************************************************************************

tab ofsted
replace ofsted=. if ofsted==99 

********************************************************************************
*  Appendix Table A.2: Summary statistics of time spent with child (in minutes)
********************************************************************************

sutex reading_weektotal talking_weektotal helping_weektotal playing_weektotal ///
other_weektotal total_week, minmax lab title("Parental time spent with child (in minutes)") ///
file(tableA2.tex) key(tab:timeinvestments) replace


********************************************************************************
*  Appendix Table A.3: Summary statistics of material investments (per month) 
********************************************************************************

sutex books educational societies tuition fees totalexp, minmax key(tab:materialinvestments) lab ///
title("Material investments per month (in pounds)") file(tableA3.tex) replace 


**********************************************************************************************************************************
**********************************************************************************************************************************
*     SECTION 4.2: Parental beliefs about production technology
**********************************************************************************************************************************
**********************************************************************************************************************************

* preserve and reshape data  
preserve 
gen inc1=J_lowlow 
gen inc2=J_lowhigh
gen inc3=J_highlow
gen inc4=J_highhigh
gen inc5=S_lowlow
gen inc6=S_lowhigh
gen inc7=S_highlow
gen inc8=S_highhigh

reshape long inc, i(id) j(scenario) 
label define scenariolabel 1 "Jones - low time, low material" 2 "Jones - low time, high material" 3 "Jones - high time, low material" 4 "Jones - high time, high material" ///
5 "Smiths - low time, low material" 6 "Smiths - low time, high material" 7 "Smiths - high time, low material" 8 "Smiths - high time, high material"
label values scenario scenariolabel 

* generate log perceived earnings in the scenarios 
gen loginc=log(inc)

*Generate dummy variables indicating whether investments are high as well as interactions 
gen schoolquality=0
replace schoolquality=1 if scenario == 1 | scenario == 2 | scenario == 3 | scenario == 4

gen hightime=0
replace hightime=1 if scenario == 3 | scenario == 4 | scenario == 7 | scenario == 8

gen highmaterial=0
replace highmaterial=1 if scenario == 2 | scenario == 4 | scenario == 6 | scenario == 8 

gen inter_qualitytime=schoolquality*hightime
gen inter_qualitymaterial=schoolquality*highmaterial
gen inter_timematerial=hightime*highmaterial

label var scenario "Type of Scenario"
label var schoolquality "High school quality"
label var hightime "High time investment"
label var highmaterial "High material investment"
label var inter_qualitytime "School x Time"
label var inter_qualitymaterial "School x Material"
label var inter_timematerial "Time x Material"
label var inc "Expected income in scenario"


********************************************************************************
*  Table 4 Determinants of perceived earnings and log perceived earnings
********************************************************************************
xtset id scenario
local weight [pw=weight]

est clear
sum inc
scalar b1=r(mean)
eststo: reg inc schoolquality hightime highmaterial `weight', r cluster(id)
estadd scalar Cmean=b1
estadd local fixed "No"

sum inc
scalar b1=r(mean)
eststo:  xtreg inc schoolquality hightime highmaterial `weight', fe r cluster(id)
estadd scalar Cmean=b1
estadd local fixed "Yes"

sum inc
scalar b1=r(mean)
eststo:  xtreg inc schoolquality hightime highmaterial inter_qualitytime ///
inter_qualitymaterial inter_timematerial `weight', fe r cluster(id)
estadd scalar Cmean=b1
estadd local fixed "Yes"

sum inc if inc!=0
scalar b1=r(mean)
eststo: reg loginc schoolquality hightime highmaterial `weight', r cluster(id)
estadd scalar Cmean=b1
estadd local fixed "No"

sum inc if inc!=0
scalar b1=r(mean)
eststo:  xtreg loginc schoolquality hightime highmaterial `weight', fe r cluster(id)
estadd scalar Cmean=b1
estadd local fixed "Yes"

sum inc if inc!=0 
scalar b1=r(mean)
eststo:  xtreg loginc schoolquality hightime highmaterial inter_qualitytime ///
inter_qualitymaterial inter_timematerial `weight', fe r cluster(id)
estadd scalar Cmean=b1
estadd local fixed "Yes"

esttab using table4.tex, se s(Cmean fixed N r2, label("Sample mean" "Respondent fixed effects" "Observations" "R-squared") fmt(0 0 0 3)) ///
nomtitle title(Determinants of (log) perceived earnings at age 30) ///
nonotes addnotes(Robust standard errors in parentheses. * p $<$ 0.10, ** p $<$ 0.05, *** p $<$ 0.01) ///
b(%8.3f) se(0) label nobaselevels compress nodepvars replace

***********************************************************************
*  Table 5: Determinants of log perceived earnings by level and skill 
***********************************************************************

* By group 0/group 1

est clear
sum inc if group1==0 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if group1==0 
est store spec1
estadd scalar Cmean=b1
estadd local fixed "No"

sum inc if group1==1 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if group1==1 
est store spec2
estadd scalar Cmean=b1
estadd local fixed "No"

suest spec1 spec2, r cluster(id)
foreach i in schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial inter_timematerial _cons {
test [spec1_mean]`i' = [spec2_mean]`i'
}
 
* By skill level
sum inc if smart==0 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if smart==0 
est store spec3
estadd scalar Cmean=b1
estadd local fixed "No"

sum inc if smart==1 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if smart==1 
est store spec4
estadd scalar Cmean=b1
estadd local fixed "No"

suest spec3 spec4, r cluster(id)
foreach i in schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial inter_timematerial _cons {
test [spec3_mean]`i' = [spec4_mean]`i'
}
 
#delimit ;
esttab  spec1 spec2 spec3 spec4    
using table5.tex, replace label compress  b(%8.3f) se(3) 
title(Determinants of log perceived earnings at age 30 (2)) star(* 0.1 ** 0.05 *** 0.01) 
nonotes addnotes(Robust standard errors in parentheses. * p $<$ 0.10, ** p $<$ 0.05, *** p $<$ 0.01)
s(Cmean r2 N, labels("Sample Mean" "R-Squared" "Observations") fmt(0  2 0)) nodepvars  
extracols(3 6)
mtitle("Group 0" "Group 1" "Low ability" "High ability")
mgroups("Initial Level" "Initial Skill", pattern( 1 0 1 0  ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
;
#delimit cr

***********************************************************************
*  Table 6: Determinants of log perceived earnings by gender and age
***********************************************************************
est clear

*By gender
sum inc if boys==0 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if boys==0 
est store spec1
estadd scalar Cmean=b1
estadd local fixed "No"

sum inc if boys==1 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if boys==1 
est store spec2
estadd scalar Cmean=b1
estadd local fixed "No"

suest spec1 spec2, r cluster(id)
foreach i in schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial inter_timematerial _cons {
test [spec1_mean]`i' = [spec2_mean]`i'
}

*By time/age
sum inc if primary==0 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if primary==0 
est store spec3
estadd scalar Cmean=b1
estadd local fixed "No"

sum inc if primary==1 & inc!=0
scalar b1=r(mean)
qui reg loginc schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial ///
inter_timematerial if primary==1 
est store spec4
estadd scalar Cmean=b1
estadd local fixed "No"

suest spec3 spec4, r cluster(id)
foreach i in schoolquality hightime highmaterial inter_qualitytime inter_qualitymaterial inter_timematerial _cons {
test [spec3_mean]`i' = [spec4_mean]`i'
}

#delimit ;
esttab  spec1 spec2 spec4 spec3   
using table6.tex, replace label compress  b(%8.3f) se(3)  
title(Determinants of log perceived earnings at age 30 (3)) star(* 0.1 ** 0.05 *** 0.01) 
nonotes addnotes(Robust standard errors in parentheses. * p $<$ 0.10, ** p $<$ 0.05, *** p $<$ 0.01)
extracols(3 6)
s(Cmean  r2 N, labels("Sample Mean"  "R-Squared" "Observations") fmt(0   2 0)) nodepvars  
mtitle("Female" "Male" "Year 3" "Year 7")
mgroups("Gender" "Age", pattern( 1 0 1 0  ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
;
#delimit cr
 
est clear



***********************************************************************
* Figure 1: Expected earnings under hypothetical scenarios 
***********************************************************************

* Find mean and standard error of mean over the three dimensions (school quality, hightime and highmaterial)
collapse (mean) mean_inc=inc (sem) sem_inc=inc (count) n_inc=inc, by(scenario)
gen inc_upper= mean_inc + invttail(n_inc-1,0.025)*sem_inc
gen inc_lower= mean_inc - invttail(n_inc-1,0.025)*sem_inc

*generate scenario variables one more time 
gen schoolquality=0
replace schoolquality=1 if scenario == 1 | scenario == 2 | scenario == 3 | scenario == 4

gen hightime=0
replace hightime=1 if scenario == 3 | scenario == 4 | scenario == 7 | scenario == 8

gen highmaterial=0
replace highmaterial=1 if scenario == 2 | scenario == 4 | scenario == 6 | scenario == 8

*generate auxiliary variable for graph 
gen combine=0
replace combine=1 if scenario==1 | scenario==5
replace combine=2.5 if scenario==2 | scenario==6
replace combine=4 if scenario==3 | scenario==7
replace combine=5.5 if scenario==4 | scenario==8

graph drop _all
twoway (bar mean_inc combine if schoolquality==0 & highmaterial==0 & combine == 1, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs0)) ///
(bar mean_inc combine if schoolquality==0 & highmaterial==1 & combine == 2.5, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs4)) ///
(bar mean_inc combine if schoolquality==0 & highmaterial==0 & combine == 4, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs10)) ///
(bar mean_inc combine if schoolquality==0 & highmaterial==1 & combine == 5.5, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs14)) ///
(rcap inc_upper inc_lower combine if schoolquality==0, color(black))  ///
   ,  ///
xlabel("" , noticks) ///
legend(row(2) order(1 "Low material/Low time" 2 "High material/Low time" 3 "Low material/High time" 4 "High material/High time" ) size(small)) ///
plotregion(fcolor(white)) graphregion(fcolor(white)) ytitle("")  xtitle("")    /// 
subtitle("Low school quality (Smiths)")  name(fig1)

twoway (bar mean_inc combine if schoolquality==1 & highmaterial==0 & combine == 1, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs0)) ///
(bar mean_inc combine if schoolquality==1 & highmaterial==1 & combine == 2.5, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs4)) ///
(bar mean_inc combine if schoolquality==1 & highmaterial==0 & combine == 4, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs10)) ///
(bar mean_inc combine if schoolquality==1 & highmaterial==1 & combine == 5.5, base(0) ysca(r(45000)) ytick(0(5000)45000)  ylabel(0(10000)45000) color(gs14)) ///
(rcap inc_upper inc_lower combine if schoolquality==1, color(black)) ///
 ,  ///
xlabel("" , noticks)  ///
legend(row(2) order(1 "Low material/Low time" 2 "High material/Low time" 3 "Low material/High time" 4 "High material/High time" ) size(small)) ///
plotregion(fcolor(white)) graphregion(fcolor(white)) ytitle("")  xtitle("")    ///
subtitle("High school quality (Jones)")  name(fig2) 
 
grc1leg fig1 fig2 , legendfrom(fig1)  plotregion(fcolor(white)) graphregion(fcolor(white)) 
graph export figure1.png,replace
graph export figure1.eps,replace

*restore data 
restore 



**********************************************************************************************************************************
**********************************************************************************************************************************
*     SECTION 4.3: Heterogeneity in perceived returns
**********************************************************************************************************************************
**********************************************************************************************************************************

* Note: use original data that is not reshaped 

* calculating perceived returns for each individual to each of the three investments (in percent)  
gen r_schoolquality=(((J_lowlow-S_lowlow)/S_lowlow)+((J_lowhigh-S_lowhigh)/S_lowhigh)+((J_highlow-S_highlow)/S_highlow)+((J_highhigh-S_highhigh)/S_highhigh))/4
gen r_time=(((J_highlow-J_lowlow)/J_lowlow)+((J_highhigh-J_lowhigh)/J_lowhigh)+((S_highlow-S_lowlow)/S_lowlow)+((S_highhigh-S_lowhigh)/S_lowhigh))/12
gen r_material=(((J_lowhigh-J_lowlow)/J_lowlow)+((J_highhigh-J_highlow)/J_highlow)+((S_lowhigh-S_lowlow)/S_lowlow)+((S_highhigh-S_highlow)/S_highlow))/12

label var r_schoolquality "Perceived returns (quality)"
label var r_time "Perceived returns (time)"
label var r_material "Perceived returns (material)"

* calculating perceived returns for each individual to each of the three investments (in levels)
gen r_schoolquality_level=((J_lowlow-S_lowlow)+(J_lowhigh-S_lowhigh)+(J_highlow-S_highlow)+(J_highhigh-S_highhigh))/4
gen r_time_level=((J_highlow-J_lowlow)+(J_highhigh-J_lowhigh)+(S_highlow-S_lowlow)+(S_highhigh-S_lowhigh))/12
gen r_material_level=((J_lowhigh-J_lowlow)+(J_highhigh-J_highlow)+(S_lowhigh-S_lowlow)+(S_highhigh-S_highlow))/12

label var r_schoolquality_level "Return to school quality (Level)"
label var r_time_level "Return to time investments (Level)"
label var r_material_level "Return to material investments (Level)"

* generate income quartiles 
xtile incquartile=hhincome, nq(4) 
gen secondquartile=(incquartile==2) if !missing(incquartile) 
gen thirdquartile=(incquartile==3) if !missing(incquartile) 
gen fourthquartile=(incquartile==4) if !missing(incquartile) 

label var secondquartile "2nd income quartile" 
label var thirdquartile "3rd income quartile" 
label var fourthquartile "4th income quartile" 

****************************************
*Table 7: Spearman correlations table 
****************************************
  
spearman r_time r_material r_schoolquality , star(0.01)
matrix spear=r(Rho)
outtable using table7, mat(spear) caption(Spearman rank correlations for perceived returns \label{tab:spearman}) nobox format(%9.3f) replace

****************************************
*Figure 2: Joint distributions of individual perceived returns 
****************************************

* Generate contour plots of perceived returns (in %) in Matlab. 

****************************************
*Table 8: Determinants of parental perceptions
****************************************
 
local controls01  parent_male parent_age i.region totalchildren otheradult work_fulltime oneparentuni private ///
secondquartile thirdquartile fourthquartile academic schoolyear child_male child_age otherlanguage   

   foreach i in J_lowlow r_schoolquality_level r_time_level r_material_level r_schoolquality r_time r_material   {
if "`i'"=="J_lowlow" {
		local what 1
	}
	
	if "`i'"=="r_time_level" {
		local what 2
	}
	if "`i'"=="r_material_level" {
		local what 3
	}
	
	if "`i'"=="r_schoolquality_level" {
		local what 4
	}
	
		if "`i'"=="r_time" {
		local what 5
	}
	if "`i'"=="r_material" {
		local what 6
	}
	
	if "`i'"=="r_schoolquality" {
		local what 7
	}
	
	 		
sum `i'
scalar b1=r(mean)
qui reg `i' `controls01'  `weight', r
estimates store regression`what'
estadd scalar Cmean=b1
}

esttab  regression1 regression2 regression3 regression4 regression5 regression6 regression7 using table8.tex, replace label compress  b(%8.3f) se(3) ///
title(Determinants of perceived returns \label{tab:returnsdeterminants}) booktabs star(* 0.1 ** 0.05 *** 0.01) ///
nonotes addnotes(Notes: regional fixed effects are included)  ///
s(Cmean r2 N, labels("Sample Mean" "R-squared" "Observations" N) fmt(2 3 0)) nodepvars ///
mtitle("Baseline" "Time" "Material" "School" "Time" "Material" "School") longtable noomit nogaps nonumbers keep(parent_male parent_age ///
totalchildren otheradult work_fulltime oneparentuni private  secondquartile thirdquartile fourthquartile academic schoolyear child_male child_age otherlanguage)
est clear


****************************************************************************************************************
****************************************************************************************************************
* SECTION 4.4: Do perceived returns predict current parental investments?
****************************************************************************************************************
*****************************************************************************************************************

* generate factors 
fac reading_weektotal talking_weektotal helping_weektotal playing_weektotal other_weektotal, pcf fac(1)
predict activities
label var activities "Activities"

fac books educational societies tuition, pcf fac(1)
predict expenditure
label var expenditure "Expenditure"
 
************************************************************************
* Table 9: Own parental TIME investments 
************************************************************************
 
local controls parent_male parent_age i.region totalchildren otheradult work_fulltime oneparentuni private ///
secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage
 
foreach i in reading_weektotal helping_weektotal talking_weektotal playing_weektotal other_weektotal total_week activities {
	if "`i'"=="reading_weektotal" {
		local what 1
	}
	if "`i'"=="helping_weektotal" {
		local what 2
	}
	if "`i'"=="talking_weektotal" {
		local what 3
	}
	if "`i'"=="playing_weektotal" {
		local what 4
	}
	if "`i'"=="other_weektotal" {
		local what 5
	}
	if "`i'"=="total_week" {
		local what 6
	}
	if "`i'"=="activities" {
		local what 7
	}
sum `i'
scalar b1=r(mean)
qui reg `i' r_time r_material r_schoolquality   `controls' `weight', r
estimates store regression`what'
estadd scalar Cmean=b1
}
esttab regression1 regression2 regression3 regression4 regression5 regression6 regression7 using table9.tex, replace label compress  b(%8.3f) se(3) ///
title(Weekly time investments (in minutes) \label{tab:owntimeinvestments_all}) booktabs star(* 0.1 ** 0.05 *** 0.01) ///
s(Cmean r2 N, labels("Sample Mean" "R-squared" "Observations" N) fmt(2 3 0)) nodepvars ///
mtitle("Reading" "Helping" "Talking" "Playing" "Other" "Total" "Activities")  noomit nogaps nonumbers ///
mgroups("Weekly investments" "Factor", pattern( 1 0 0 0 0 0 1 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
keep(r_time r_material r_schoolquality  parent_male parent_age totalchildren otheradult  work_fulltime oneparentuni private  ///
secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage)
 
*************************************************************************
* Table 10: Own parental MATERIAL investments
**************************************************************************
 
foreach i in books educational societies tuition totalexp expenditure {
	if "`i'"=="books"{
		local what 1
	}
	if "`i'"=="educational"{
		local what 2
	}
	if "`i'"=="societies"{
		local what 3
	}
	if "`i'"=="tuition"{
		local what 4
	}
	if "`i'"=="totalexp"{
		local what 5
	}
	if "`i'"=="expenditure"{
		local what 6
	}
sum `i' 
scalar b1=r(mean)
qui reg `i' r_time r_material r_schoolquality  `controls' `weight', r
estimates store regression`what'
estadd scalar Cmean=b1
}
esttab regression1 regression2 regression3 regression4 regression5 regression6 using table10.tex, replace label compress  b(%8.3f) se(3) ///
title(Monthly material investments (in pounds) \label{tab:ownmaterialinvestments_all}) booktabs star(* 0.1 ** 0.05 *** 0.01) ///
s(Cmean r2 N, labels("Sample Mean" "R-squared" "Observations" N) fmt(2 3 0)) nodepvars ///
mtitle("Books" "Educ. games" "Societies" "Tuition" "Total" "Expenditure")  noomit nogaps nonumbers ///
mgroups("Weekly investments" "Factor", pattern( 1 0 0 0 0 1 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
keep(r_time r_material r_schoolquality  parent_male parent_age totalchildren otheradult work_fulltime oneparentuni private ///
secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage)

*****************************************************************************
*  Table 11: Own parental SCHOOL QUALITY investments
*****************************************************************************
 
local controls parent_male parent_age i.region totalchildren otheradult  ///
work_fulltime oneparentuni secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage

foreach i in ofsted fees {
	if "`i'"=="ofsted" {
		local what 1
	}
	if "`i'"=="fees" {
		local what 2
	}
sum `i'
scalar b1=r(mean) 
reg `i' r_time r_material r_schoolquality  `controls' `weight', r
estimates store regression`what'
estadd scalar Cmean=b1
}
esttab regression1 regression2 using table11.tex, replace label compress  b(%8.3f) se(3) ///
title(Own school quality investments \label{tab:ownschoolquality_all}) booktabs star(* 0.1 ** 0.05 *** 0.01) ///
s(Cmean r2 N, labels("Sample Mean" "R-squared" "Observations" N) fmt(2 3 0)) nodepvars ///
mtitle("Quality" "Fees")  noomit nogaps nonumbers ///
keep(r_time r_material r_schoolquality  parent_male parent_age totalchildren otheradult  ///
work_fulltime oneparentuni secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage)
est clear
 
 
************************************************************************
* Appendix Tables A.4/A.5/A.6: limit analysis to those for whom the perceived returns are non-negative
************************************************************************
gen r_time_nonneg=r_time
replace r_time_nonneg=. if r_time<0

gen r_material_nonneg=r_material
replace r_material_nonneg=. if r_material<0

gen r_schoolquality_nonneg=r_schoolquality 
replace r_schoolquality_nonneg=. if r_schoolquality<0 

label var r_schoolquality_nonneg "Perceived returns (quality)"
label var r_time_nonneg "Perceived returns (time)"
label var r_material_nonneg "Perceived returns (material)"
 
************************************************************************
* Table A.4: Own parental TIME investments 
************************************************************************
 
local controls parent_male parent_age i.region totalchildren otheradult work_fulltime oneparentuni private ///
secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage
 
foreach i in reading_weektotal helping_weektotal talking_weektotal playing_weektotal other_weektotal total_week activities {
	if "`i'"=="reading_weektotal" {
		local what 1
	}
	if "`i'"=="helping_weektotal" {
		local what 2
	}
	if "`i'"=="talking_weektotal" {
		local what 3
	}
	if "`i'"=="playing_weektotal" {
		local what 4
	}
	if "`i'"=="other_weektotal" {
		local what 5
	}
	if "`i'"=="total_week" {
		local what 6
	}
	if "`i'"=="activities" {
		local what 7
	}
sum `i'
scalar b1=r(mean)
qui reg `i' r_time_nonneg r_material_nonneg r_schoolquality_nonneg   `controls' `weight', r
estimates store regression`what'
estadd scalar Cmean=b1
}
esttab regression1 regression2 regression3 regression4 regression5 regression6 regression7 using tableA4.tex, replace label compress  b(%8.3f) se(3) ///
title(Weekly time investments (in minutes) \label{tab:owntimeinvestments_all}) booktabs star(* 0.1 ** 0.05 *** 0.01) ///
s(Cmean r2 N, labels("Sample Mean" "R-squared" "Observations" N) fmt(2 3 0)) nodepvars ///
mtitle("Reading" "Helping" "Talking" "Playing" "Other" "Total" "Activities")  noomit nogaps nonumbers ///
mgroups("Weekly investments" "Factor", pattern( 1 0 0 0 0 0 1 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
keep(r_time_nonneg r_material_nonneg r_schoolquality_nonneg  parent_male parent_age totalchildren otheradult  work_fulltime oneparentuni private  ///
secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage)
 
 
 
**************************************************************************
* Table A.5: Own parental MATERIAL investments
**************************************************************************
 
foreach i in books educational societies tuition totalexp expenditure {
	if "`i'"=="books"{
		local what 1
	}
	if "`i'"=="educational"{
		local what 2
	}
	if "`i'"=="societies"{
		local what 3
	}
	if "`i'"=="tuition"{
		local what 4
	}
	if "`i'"=="totalexp"{
		local what 5
	}
	if "`i'"=="expenditure"{
		local what 6
	}
sum `i' 
scalar b1=r(mean)
qui reg `i' r_time_nonneg r_material_nonneg r_schoolquality_nonneg  `controls' `weight', r
estimates store regression`what'
estadd scalar Cmean=b1
}
esttab regression1 regression2 regression3 regression4 regression5 regression6 using tableA5.tex, replace label compress  b(%8.3f) se(3) ///
title(Monthly material investments (in pounds) \label{tab:ownmaterialinvestments_all}) booktabs star(* 0.1 ** 0.05 *** 0.01) ///
s(Cmean r2 N, labels("Sample Mean" "R-squared" "Observations" N) fmt(2 3 0)) nodepvars ///
mtitle("Books" "Educ. games" "Societies" "Tuition" "Total" "Expenditure")  noomit nogaps nonumbers ///
mgroups("Weekly investments" "Factor", pattern( 1 0 0 0 0 1 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
keep(r_time_nonneg r_material_nonneg r_schoolquality_nonneg  parent_male parent_age totalchildren otheradult work_fulltime oneparentuni private ///
secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage)

*****************************************************************************
*  Table A.6: Own parental SCHOOL QUALITY investments
*****************************************************************************
 
local controls parent_male parent_age i.region totalchildren otheradult  ///
work_fulltime oneparentuni secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage

foreach i in ofsted fees {
	if "`i'"=="ofsted" {
		local what 1
	}
	if "`i'"=="fees" {
		local what 2
	}
sum `i'
scalar b1=r(mean) 
reg `i' r_time_nonneg r_material_nonneg r_schoolquality_nonneg  `controls' `weight', r
estimates store regression`what'
estadd scalar Cmean=b1
}
esttab regression1 regression2 using tableA6.tex, replace label compress  b(%8.3f) se(3) ///
title(Own school quality investments \label{tab:ownschoolquality_all}) booktabs star(* 0.1 ** 0.05 *** 0.01) ///
s(Cmean r2 N, labels("Sample Mean" "R-squared" "Observations" N) fmt(2 3 0)) nodepvars ///
mtitle("Quality" "Fees")  noomit nogaps nonumbers ///
keep(r_time_nonneg r_material_nonneg r_schoolquality_nonneg  parent_male parent_age totalchildren otheradult  ///
work_fulltime oneparentuni secondquartile thirdquartile fourthquartile  academic schoolyear child_male child_age otherlanguage)
est clear


****************************************
* Figure A.2: Distributions of individual perceived returns 
****************************************
preserve 
 
graph drop _all 
gen uff = 1

foreach t in schoolquality time material {
	sort uff r_`t'
	sum r_`t'
	by uff: gen cum_uff=sum(uff)
	gen cum_`t' = cum_uff / `r(N)'
	drop cum_uff
}

keep cum_schoolquality cum_time cum_material r_schoolquality r_time r_material
save temp, replace

foreach j in schoolquality time material {
	use temp
	keep *`j'
	rename cum_`j' cum
	sort cum 
	save `j', replace
}

use schoolquality
sort cum
merge cum using time material

collapse (max) r_schoolquality r_time r_material, by(cum)
keep if cum<= 1

twoway (line cum r_schoolquality if r_schoolquality < 1.5, lcolor(black)  lpattern(dash) lwidth(thick) ) ///
	(line cum r_time , lcolor(gs0) lwidth(thick)) 	///
	(line cum r_material , lcolor(gs12) lwidth(thick)) 	, ///
	 xlabel(-0.4(0.2)1.4) xtitle("Perceived return") legend(row(1) order (1 "School quality" 2  "Time" 3 "Material") ) plotregion(fcolor(white)) graphregion(fcolor(white)) ytitle("")   ///
	 ylabel(0(0.2)1)

graph export figureA2.png, replace
graph export figureA2.eps, replace	
 
restore
